@@ -9,7 +9,8 @@ fn main() {
         states::SetACMode::Cool,
         Some(states::ACFanSpeed::Powerful),
         states::SetACSetpoint::Value(22),
-    );
+    )
+    .build();
 
     // Logic to send TCP packet
 }
