@@ -1,7 +1,23 @@
 use crate::states;
 
+use super::MessageType;
+
+/// This packet is sent to the AT4 unit to request all AC unit data.
+pub const GET_AC_STATUS_PACKET: [u8; 10] = [
+    0x55,
+    0x55,
+    0x80,
+    0xb0,
+    0x01,
+    MessageType::AC_STATUS_MESSAGE,
+    0,
+    0,
+    0xf4,
+    0xcf,
+];
+
 /// The state of an AC unit.
-#[derive(Debug, PartialEq)]
+#[derive(Debug, PartialEq, Clone, Copy)]
 pub struct ACStatus {
     pub power_state: Option<states::ACPowerState>,
     /// Valid values are `0`-`3`.
