@@ -1,5 +1,21 @@
 use crate::states;
 
+use super::MessageType;
+
+/// This packet is sent to the AT4 unit to request all group data.
+pub const GET_GROUP_STATUS_PACKET: [u8; 10] = [
+    0x55,
+    0x55,
+    0x80,
+    0xb0,
+    0x01,
+    MessageType::GROUP_STATUS_MESSAGE,
+    0,
+    0,
+    0xf5,
+    0x2f,
+];
+
 /// The state of a group.
 #[derive(Debug, PartialEq, Clone, Copy)]
 pub struct GroupStatus {
