@@ -6,9 +6,9 @@ mod group_control_message;
 mod group_status_message;
 
 pub use ac_control_message::ACControlMessage;
-pub use ac_status_message::ACStatus;
+pub use ac_status_message::{ACStatus, GET_AC_STATUS_PACKET};
 pub use group_control_message::GroupControlMessage;
-pub use group_status_message::GroupStatus;
+pub use group_status_message::{GroupStatus, GET_GROUP_STATUS_PACKET};
 
 struct MessageType;
 
