@@ -1,7 +1,4 @@
 use super::parse_message;
-use super::GroupControlMessage;
-
-use crate::states;
 
 #[test]
 #[should_panic(expected = "bytes length is too short to be a valid AT4 message.")]
@@ -45,7 +42,7 @@ fn test_parses_message() {
     ]);
 
     match result {
-        Err(reason) => println!("error: {}", reason),
-        _ => {}
+        Err(reason) => panic!("error: {}", reason),
+        Ok(m) => println!("msg: {:#?}", m),
     }
 }
